# Changelog

## 0.1.0-alpha.4 (2024-08-14)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/mainstay-io/mainstay-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* add parallelized calls code ([91f3c4c](https://github.com/mainstay-io/mainstay-python/commit/91f3c4cdd62befe8f1407e7fc0171540fede450e))
* added crime and school parallelized calls ([7edfa2e](https://github.com/mainstay-io/mainstay-python/commit/7edfa2eec3556edb72f85fa36742c37b17cd4a72))
* clean up on top of the diffs + questions ([ebef7e7](https://github.com/mainstay-io/mainstay-python/commit/ebef7e7b65092f6bd7b6932428ac65b44b1b60e4))
* copied changes ([76364b7](https://github.com/mainstay-io/mainstay-python/commit/76364b79a730c71eb119551c445fd92516a62edf))
* fix imports ([1165409](https://github.com/mainstay-io/mainstay-python/commit/11654099fb2e5c0eccd4f37c3dc10f2b763eb6c9))
* fix names ([f96c489](https://github.com/mainstay-io/mainstay-python/commit/f96c489241b9e1c4da39a33b6bfa4082a71382de))
* fixed examples files linting ([26c4a60](https://github.com/mainstay-io/mainstay-python/commit/26c4a60deabe2bb7b5a621199ed6a7c97167875d))
* revert all the accidental custom codes, keep only the parallelized calls ([bb045b7](https://github.com/mainstay-io/mainstay-python/commit/bb045b7770017fb08891845a436c826e5f9310f5))

## 0.1.0-alpha.3 (2024-08-13)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/mainstay-io/mainstay-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** manual updates ([#15](https://github.com/mainstay-io/mainstay-python/issues/15)) ([6b3e125](https://github.com/mainstay-io/mainstay-python/commit/6b3e125658144d4f687bb9ccfa6dd9eedaa57624))
* **api:** OpenAPI spec update via Stainless API ([#16](https://github.com/mainstay-io/mainstay-python/issues/16)) ([8a2263a](https://github.com/mainstay-io/mainstay-python/commit/8a2263a1b99f3dc3cde7c96a64ea1f6da9273ce3))


### Chores

* **examples:** minor formatting changes ([#10](https://github.com/mainstay-io/mainstay-python/issues/10)) ([ccf2d18](https://github.com/mainstay-io/mainstay-python/commit/ccf2d18a1c89a3dd1e2104de4e9a1a5ddefcd888))
* **internal:** codegen related update ([#13](https://github.com/mainstay-io/mainstay-python/issues/13)) ([69c2224](https://github.com/mainstay-io/mainstay-python/commit/69c222485cc5a0580b51b13609f8a503e8bfb5e9))
* **internal:** version bump ([#11](https://github.com/mainstay-io/mainstay-python/issues/11)) ([b584ac1](https://github.com/mainstay-io/mainstay-python/commit/b584ac161dc6915e58e6fc161e06604985c1ad40))

## 0.1.0-alpha.2 (2024-08-10)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/mainstay-io/mainstay-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Chores

* **ci:** bump prism mock server version ([#6](https://github.com/mainstay-io/mainstay-python/issues/6)) ([1f9d7f8](https://github.com/mainstay-io/mainstay-python/commit/1f9d7f817d34419f9603c25f1206678706db5e57))
* **internal:** ensure package is importable in lint cmd ([#8](https://github.com/mainstay-io/mainstay-python/issues/8)) ([c49ec2b](https://github.com/mainstay-io/mainstay-python/commit/c49ec2b58d18671eaea432058367f95645ec3d39))

## 0.1.0-alpha.1 (2024-08-10)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/mainstay-io/mainstay-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** OpenAPI spec update via Stainless API ([9cd559e](https://github.com/mainstay-io/mainstay-python/commit/9cd559e96e2d154346a17d225bdea3a3ad3d78b6))
* **api:** OpenAPI spec update via Stainless API ([ab54c3c](https://github.com/mainstay-io/mainstay-python/commit/ab54c3c0b590cd2197359984da5242bfebe2ebe8))


### Chores

* go live ([#2](https://github.com/mainstay-io/mainstay-python/issues/2)) ([e8fb3e5](https://github.com/mainstay-io/mainstay-python/commit/e8fb3e5bc68c7b4fc331e9ac9fba91d7a8bf0120))
